@@ -1,5 +1,5 @@
 """Turbulette root package."""
 
 from .main import setup  # noqa
-from .asgi.mounts import turbulette_starlette  # noqa
+from .asgi import turbulette_starlette  # noqa
 from .apps.base import query, mutation  # noqa
