@@ -8,7 +8,7 @@ from typing import Dict, List, Type
 from ariadne import SchemaDirectiveVisitor, load_schema_from_path
 from pydantic import BaseModel
 
-from turbulette.core.validation.pyd_model import GraphQLModel
+from turbulette.validation.pyd_model import GraphQLModel
 
 from .constants import (
     FOLDER_SCHEMA,
@@ -163,11 +163,11 @@ class TurbuletteApp:
             for _, member in getmembers(module, isclass):
                 if (
                     issubclass(member, BaseModel)
-                    and hasattr(member, "__type__")
+                    and hasattr(member, "GraphQL")
                     and member is not BaseModel
                     and member is not GraphQLModel
                 ):
-                    models[member.__type__] = member
+                    models[member.GraphQL.gql_type] = member
         return models
 
     def __bool__(self):
