@@ -20,13 +20,14 @@ ENV_TURBULETTE_SETTINGS = "TURBULETTE_SETTINGS"
 # Files and folders
 FILE_ALEMBIC_INI = "alembic.ini"
 FOLDER_ALEMBIC = "alembic"
-
+FOLDER_MIGRATIONS = "migrations"
 
 # Apps that must always be loaded with turbulette
-TURBULETTE_CORE_APPS = [
-    "turbulette.apps.base"
-]
+TURBULETTE_CORE_APPS = ["turbulette.apps.base"]
 
 
 # pytest settings
 PYTEST_TURBULETTE_SETTINGS = "PYTEST_TURBULETTE_SETTINGS"
+
+TURBULETTE_ROUTING_MODULE = "routing"
+ROUTING_MODULE_ROUTES = "routes"
